==> flowable-engine-6.1.0-sources.jar: org/flowable/engine/compatibility/DefaultFlowable5CompatibilityHandlerFactory.java <==
/* Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.flowable.engine.compatibility;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * @author Joram Barrez
 */
public class DefaultFlowable5CompatibilityHandlerFactory implements Flowable5CompatibilityHandlerFactory {

    private static final Logger logger = LoggerFactory.getLogger(DefaultFlowable5CompatibilityHandlerFactory.class);

    protected String compatibilityHandlerClassName;

    @Override
    public Flowable5CompatibilityHandler createFlowable5CompatibilityHandler() {

        if (compatibilityHandlerClassName == null) {
            compatibilityHandlerClassName = "org.flowable.compatibility.DefaultFlowable5CompatibilityHandler";
        }

        try {
            Flowable5CompatibilityHandler handler = (Flowable5CompatibilityHandler) Class.forName(compatibilityHandlerClassName).newInstance();
            return handler;
        } catch (Exception e) {
            logger.info("Flowable 5 compatibility handler implementation not found or error during instantiation : {}. Flowable 5 backwards compatibility disabled.",
                    e.getMessage());
        }
        return null;
    }

    public String getCompatibilityHandlerClassName() {
        return compatibilityHandlerClassName;
    }

    public void setCompatibilityHandlerClassName(String compatibilityHandlerClassName) {
        this.compatibilityHandlerClassName = compatibilityHandlerClassName;
    }

}

==> flowable-engine-6.7.0-sources.jar: org/flowable/engine/compatibility/DefaultFlowable5CompatibilityHandlerFactory.java <==
/* Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.flowable.engine.compatibility;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * @author Joram Barrez
 */
public class DefaultFlowable5CompatibilityHandlerFactory implements Flowable5CompatibilityHandlerFactory {

    private static final Logger LOGGER = LoggerFactory.getLogger(DefaultFlowable5CompatibilityHandlerFactory.class);

    protected String compatibilityHandlerClassName;

    @Override
    public Flowable5CompatibilityHandler createFlowable5CompatibilityHandler() {

        if (compatibilityHandlerClassName == null) {
            compatibilityHandlerClassName = "org.flowable.compatibility.DefaultFlowable5CompatibilityHandler";
        }

        try {
            Flowable5CompatibilityHandler handler = (Flowable5CompatibilityHandler) Class.forName(compatibilityHandlerClassName).newInstance();
            return handler;
        } catch (Exception e) {
            LOGGER.info("Flowable 5 compatibility handler implementation not found or error during instantiation : {}. Flowable 5 backwards compatibility disabled.",
                    e.getMessage());
        }
        return null;
    }

    public String getCompatibilityHandlerClassName() {
        return compatibilityHandlerClassName;
    }

    public void setCompatibilityHandlerClassName(String compatibilityHandlerClassName) {
        this.compatibilityHandlerClassName = compatibilityHandlerClassName;
    }

}
